@@ -16,24 +16,19 @@ function(y, minb=5, oshare=TRUE, pool=TRUE, silent=FALSE, hess=FALSE, meth="L-BF
   {
     gg<- shift2gg(GG[,i], ns)
 	w<- opt.sgs(y, gg, oshare=oshare, hess=hess, meth=meth, model=model)              
-    if (!silent) 	cat (i, "\t", GG[,i], "\t", round(w$val, 3), "\n")
-    logl[i]<- w$value
+    if (!silent) 	cat (i, "\t", GG[,i], "\t", round(w$logL, 3), "\n")
+    logl[i]<- w$logL
     wl[[i]]<- w
   }
 
  # add more information to results
+ if (!silent) cat("\n")
  winner<- which.max(logl)
  ww<- wl[[winner]]
- ww$n<- ns-1
- ww$shift.start<- GG[,winner]
- ww$AIC<- IC(ww, meth="AIC")
- ww$AICc<- IC(ww, meth="AICc")
- ww$BIC<- IC(ww, meth="BIC")
+ ss<- GG[,winner]
+ names(ss)<- paste("shift", 1:(ng-1), sep='')
+ ww$parameters<- append(ww$parameters, ss)
  ww$all.logl<- logl
  ww$GG<- GG
- if (hess)		ww$se<- sqrt(diag(-1*solve(ww$hessian)))
-
- if (!silent) cat("\n")
  return(ww)
 }
-
