@@ -18,12 +18,12 @@ function(p,x)
  VV2<- outer(VVd,VVd,pmin)
  VV<- VV*VV2
  diag(VV)<- VVd + x$vv/x$nn 	# add sampling variance
- detV<- det(VV)
- invV<- solve(VV)
+ #detV<- det(VV)
+ #invV<- solve(VV)
  
  # compute logL based on multivariate normal
  M<- ou.M(anc, theta, aa, x$tt)
- S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ #S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ S<- dmvnorm(t(x$mm), mean=M, sigma=VV, log=TRUE)
  return(S)		
 }
-
