@@ -10,12 +10,10 @@ function (p,x)
  
  # compute covariance matrix
  VV<- diag(omega + x$vv/x$nn)  # omega + sampling variance
- detV<- det(VV)
- invV<- solve(VV)
  
  # compute logL based on multivariate normal
  M<- rep(theta, n)
- S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ #S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ S<- dmvnorm(x$mm, mean=M, sigma=VV, log=TRUE)
  return(S)	 	
 }
-
