@@ -19,9 +19,9 @@ function(y, ng=2, minb=5, model=1, pool=TRUE, silent=FALSE)
     if (!silent) 	cat (i, " ")
     gg<- shift2gg(GG[,i], ns)
     yl<- split4punc(y, gg)
-    #print(yl[[1]]$)
-    if (model==1)	{ w<- opt.RW.SameVs(yl, pool=pool);  w$K<- 2*ng; }
-    if (model==2)	{ w<- opt.RW.SameMs(yl, pool=pool);  w$K<- 2*ng; }
+    #print(yl[[1]])
+    if (model==1)	{ w<- opt.RW.SameVs(yl, pool=pool); w$modelName<- paste('GRWsameVs-shift', ng-1, sep='-'); w$K<- w$K + ng-1}
+    if (model==2)	{ w<- opt.RW.SameMs(yl, pool=pool); w$modelName<- paste('GRWsameMs-shift', ng-1, sep='-'); w$K<- w$K + ng-1}
     if (model>=3)
      {
       wli<- list()
@@ -31,34 +31,31 @@ function(y, ng=2, minb=5, model=1, pool=TRUE, silent=FALSE)
        {
       	if (model==3){	
       		wli[[j]]<- opt.URW(yl[[j]], pool=pool)
-      		names(wli[[j]]$par)<- paste("vstep", j, sep="")   }
+      		names(wli[[j]]$parameters)<- paste("vstep", j, sep="")   }
       	if (model==4){	
       		wli[[j]]<- opt.GRW (yl[[j]], pool=pool)
-      		names(wli[[j]]$par)<- paste(c("mstep","vstep"), j, sep="")   }
-      	totS<- totS + wli[[j]]$value
-      	totpar<- c(totpar, wli[[j]]$par)
+      		names(wli[[j]]$parameters)<- paste(c("mstep","vstep"), j, sep="")   }
+      	totS<- totS + wli[[j]]$logL
+      	totpar<- c(totpar, wli[[j]]$parameters)
+      	kk<- length(totpar)+ng-1
        }
-      w<- list(value=totS, par=totpar, K=(model-1)*ng -1)	
+    
+      ifelse(model==3, mn<- 'URW-shift', mn<- 'GRW-shift')
+      w<- as.paleoTSfit(logL=totS, parameters=totpar, modelName=paste(mn, ng-1, sep='-'), method='AD', K=kk, n=ns-1, se=NULL)	
      }
          
-    logl[i]<- w$value
+    logl[i]<- w$logL
     wl[[i]]<- w
   }
 
  # add more information to results
  winner<- which.max(logl)
  ww<- wl[[winner]]
- ww$n<- ns-1
- ww$shift.start<- GG[,winner]
- ww$AIC<- IC(ww, meth="AIC")
- ww$AICc<- IC(ww, meth="AICc")
- ww$BIC<- IC(ww, meth="BIC")
+ ss<- GG[,winner]
+ names(ss)<- paste("shift", 1:(ng-1), sep='')
+ ww$parameters<- append(ww$parameters, ss)
  ww$all.logl<- logl
  ww$GG<- GG
- # hessian not easily recoverable in this optimization
- #if (hess)		ww$se<- sqrt(diag(-1*solve(ww$hessian)))
-
- if (!silent) cat("\n")
  return(ww)
+ 
 }
-
