@@ -5,7 +5,7 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
 {
   # get initial parameter estimates
   p0<- mle.Stasis(y)
-  if (p0[2] <= 0)	p0[2]<- 1e-7
+  if (p0[2] <= 0 || is.na(p0[2]))	p0[2]<- 1e-7
   names(p0)<- c("theta", "omega")
   if (is.null(cl$ndeps))		cl$ndeps<- abs(p0/1e4)
   
@@ -20,7 +20,7 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
   # if optim failed, set ndeps based on p0
   if (class(w)=="try-error")
     {
-	cl$ndeps<- p0/10000
+	cl$ndeps<- rep(1e-9, length(p0)) 	#p0/10000
     if (meth=="L-BFGS-B")
      w<- try(optim(p0, fn=logL.Stasis, method=meth, lower=c(NA,0), control=cl, hessian=hess, y=y), silent=TRUE)
     else 
@@ -36,13 +36,8 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
 
   # add more information to results (p0, SE, K, n, IC scores)
   if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
-  w$p0<- p0
-  w$K<- 2
-  w$n<- length(y$mm)-1
-  w$AIC<- IC(w, meth="AIC")
-  w$AICc<- IC(w, meth="AICc")
-  w$BIC<- IC(w, meth="BIC")
+  else			w$se<- NULL
+  wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName='Stasis', method='AD', K=2, n=length(y$mm)-1, se=w$se)
   
-  return (w)
+  return (wc)
 }
-
