@@ -20,8 +20,8 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
   # if optim failed, set ndeps based on p0
   if (class(w)=="try-error")
     {
-	cl$ndeps<- p0/10000
-    if (meth=="L-BFGS-B")
+	cl$ndeps<- rep(1e-9, length(p0)) 	#p0/10000
+	if (meth=="L-BFGS-B")
      w<- try(optim(p0, fn=logL.URW, method=meth, lower=0, control=cl, hessian=hess, y=y), silent=TRUE)
     else 
      w<- try(optim(p0, fn=logL.URW, method=meth, control=cl, hessian=hess, y=y), silent=TRUE)
@@ -35,14 +35,9 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
     }
 
   # add more information to results (p0, SE, K, n, IC scores)
-  if (hess)		w$se<- sqrt(-1/diag(w$hessian))
-  w$p0<- p0
-  w$K<- 1
-  w$n<- length(y$mm)-1
-  w$AIC<- IC(w, meth="AIC")
-  w$AICc<- IC(w, meth="AICc")
-  w$BIC<- IC(w, meth="BIC")
+  if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
+  else			w$se<- NULL
+  wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName='URW', method='AD', K=1, n=length(y$mm)-1, se=w$se)
   
-  return (w)
+  return (wc)
 }
-
