@@ -8,7 +8,8 @@ function (file = NULL, oldest = "first", reset.time = TRUE, ...)
     }
     else {
         x <- read.table(file = file, ...)
-        lab1 <- paste(getwd(), file)
+        #lab1 <- paste(getwd(), file)
+        lab1<- file
     }
     xr <- as.paleoTS(mm = x[, 2], vv = x[, 3], nn = x[, 1], tt = x[, 
         4], label = lab1, oldest = oldest, reset.time = reset.time)
