@@ -4,16 +4,17 @@ function (ns, ng, minb=5)
 ## dividing ns samples into ng groups of at least minb samples each
 {
   aa<- combn(ns, ng-1)
-  if (ng==2)	ok<- aa>=minb & aa<=ns-minb+1
+  #if (ng==2)	ok<- aa>=minb & aa<=ns-minb+1
+  if (ng==2)	ok<- aa>minb & aa<=ns-minb+1
   if (ng>2)
   {
     daa<- apply(aa,2,diff)
     if (ng>3)	mdaa<- apply(daa,2,min)
     else 		mdaa<- daa
     #ok1<- mdaa >= minb			# only long enough combinations
-    ok1<- mdaa >= minb-1
-    #ok2<- aa[1,] > minb 		# must start far enough from 1 for minb
-    ok2<- aa[1,] >= minb
+    ok1<- mdaa >= minb
+    ok2<- aa[1,] > minb 		# must start far enough from 1 for minb
+    #ok2<- aa[1,] >= minb
     #ok3<- aa[ng-1, ] <= ns-minb+1		# must end short of end
     ok3<- aa[ng-1,]  <= ns-minb+1
     ok<- ok1&ok2&ok3
@@ -24,4 +25,3 @@ function (ns, ng, minb=5)
   if (sum(ok)>0)	return(ret)
   else 				return(NULL)
 }
-
