@@ -1,5 +1,5 @@
 sim.punc <-
-function (ns=c(10,10), theta=c(0,1), omega=rep(0,length(theta)), nn=rep(30,sum(ns)), tt=1:sum(ns), vp=1)
+function (ns=c(10,10), theta=c(0,1), omega=rep(0,length(theta)), nn=rep(30,sum(ns)), tt=0:(sum(ns)-1), vp=1)
 # simulate punctuated sequence; theta and omega are vectors of paramters
 # ns is vector of ns in each sub-sequence
 {
@@ -26,4 +26,3 @@ function (ns=c(10,10), theta=c(0,1), omega=rep(0,length(theta)), nn=rep(30,sum(n
   names(y$genpars)<- c(paste("theta",1:nr,sep=""), paste("omega",1:nr,sep=""), paste("shift",1:(nr-1),sep=""))
   return (y)  	
 }
-
