@@ -1,5 +1,5 @@
 sim.sgs <-
-function (ns=c(20,20,20), theta=0, omega=1, ms=1, vs=0.1, nn=rep(30, times=sum(ns)), tt=1:sum(ns), vp=1)
+function (ns=c(20,20,20), theta=0, omega=1, ms=1, vs=0.1, nn=rep(30, sum(ns)), tt=0:(sum(ns)-1), vp=1)
 # simulate stasis-grw-stasis sequence, take theta2 to be final value after grw part
 {
   xl<- list()
@@ -31,4 +31,3 @@ function (ns=c(20,20,20), theta=0, omega=1, ms=1, vs=0.1, nn=rep(30, times=sum(n
   names(y$genpars)<- c("theta","omega", "ms","vs") 
   return(y)
 }
-
