@@ -9,11 +9,11 @@ function (y, gg, overlap=TRUE)
   for (i in 1:ng)
    {
    	 ok<- gg==i
-   	 if (i<ng & overlap==TRUE)
-   	 	ok[min(which(gg==i+1))]<- TRUE		# tack on next sample too
+   	 # it's counterintuitive, but the next line is correct given the interface with other functions
+   	 if (i<ng & overlap==TRUE)   ok[min(which(gg==i+1))]<- TRUE  # right!
+   	 #if(i>1 & overlap==TRUE)	ok[max(which(gg==i-1))]<- TRUE   # this is not right!
    	
    	 yl[[i]]<- as.paleoTS(y$mm[ok],y$vv[ok],y$nn[ok],y$tt[ok],y$MM[ok])
    }
   return (yl)	
 }
-
